function record=readeventrecord(filename)
  [fd,syserrmsg]=fopen(filename,'rt');
  if (fd==-1),
    msg=sprintf('Could not open %s for reading',filename);
    errmsg(msg,syserrmsg); 
  end;
  
  matchstrs=initstrings;
  record=emptyeventrecord;
  notEOF=1;
  while (notEOF),
    line=fgetl(fd);
    notEOF=ischar(line);
    if (notEOF),
      matchnum=match(line,matchstrs);
      switch matchnum,
        case 1, [videotitle]=strread(line,matchstrs(matchnum).str);
	        record.videotitle=char(videotitle);
        case 2, [videofname]=strread(line,matchstrs(matchnum).str);
	        record.videofname=char(videofname);
	case 3, [x,y,c,t]=strread(line,matchstrs(matchnum).str);
	        record.videosize=[x y c t];
	case 4, [event,lbl]=strread(line,matchstrs(matchnum).str);
	        record.events(event).label=char(lbl);
	case 5, [event,xmin,ymin,tmin,xmax,ymax,tmax]=strread(line,matchstrs(matchnum).str);
		record.events(event).predictedbbox=[xmin,ymin,tmin,xmax,ymax,tmax];
	case 6, [event,xmin,ymin,tmin,xmax,ymax,tmax]=strread(line,matchstrs(matchnum).str);
		record.events(event).observedbbox=[xmin,ymin,tmin,xmax,ymax,tmax];
	case 7, [kframe,event,lbl]=strread(line,matchstrs(matchnum).str);
	        record.events(event).keyframes(kframe).label=char(lbl);
	case 8, [kframe,event,frame]=strread(line,matchstrs(matchnum).str);
	        record.events(event).keyframes(kframe).frame=frame;
	case 9, [obj,kframe,event,lbl]=strread(line,matchstrs(matchnum).str);
	        record.events(event).keyframes(kframe).objects(obj).label=char(lbl);
	case 10,[obj,kframe,event,xmin,ymin,xmax,ymax]=strread(line,matchstrs(matchnum).str);
	        record.events(event).keyframes(kframe).objects(obj).bbox=[xmin,ymin,xmax,ymax];
        case 11,ind=find(line==':');
	        event=strread(line(1:ind-1),matchstrs(matchnum).str);
		record.events(event).description=line(ind+2:end);
	otherwise, %fprintf('Skipping: %s\n',line);
      end;
    end;
  end;
  fclose(fd);
  %fprintf('Read %d events from %s\n',length(record.events),filename)
return

function matchnum=match(line,matchstrs)
  for i=1:length(matchstrs),
    matched(i)=strncmp(line,matchstrs(i).str,matchstrs(i).matchlen);
  end;
  matchnum=find(matched);
  if isempty(matchnum), matchnum=0; end;
  if (length(matchnum)~=1), 
    errmsg('Multiple matches while parsing','');
  end;
return

function s=initstrings
  s(1).matchlen=14;
  s(1).str='Video title    : %q';
  
  s(2).matchlen=14;
  s(2).str='Video filename : %q';
  
  s(3).matchlen=10;
  s(3).str='Video size (X x Y x C x T) : %d x %d x %d x %d';
  
  s(4).matchlen=14;
  s(4).str='Label of event %d : %q';
  
  s(5).matchlen=20;
  s(5).str='Predicted bounding box of event %d (x1,y1,t1,x2,y2,t2) : (%d,%d,%d,%d,%d,%d)';
  
  s(6).matchlen=30;
  s(6).str='Observed bounding box of event %d (x1,y1,t1,x2,y2,t2) : (%d,%d,%d,%d,%d,%d)';

  s(7).matchlen=14;
  s(7).str='Label of keyframe %d, event %d : %q';
  
  s(8).matchlen=14;
  s(8).str='Frame of keyframe %d, event %d : %d';
   
  s(9).matchlen=14;
  s(9).str='Label of object %d, keyframe %d, event %d : %q';
  
  s(10).matchlen=20;
  s(10).str='Bounding Box of object %d, keyframe %d, event %d (x1,y1,x2,y2) : (%d,%d,%d,%d)';

  s(11).matchlen=18;
  s(11).str='Description of event %d';
return